==> haskell-markdown-unlit-0.5.1-111-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-markdown-unlit.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 markdown-unlit
version:              0.5.1
visibility:           public
id:                   markdown-unlit-0.5.1-KezIVwL1tmxB3EypDE04ii
key:                  markdown-unlit-0.5.1-KezIVwL1tmxB3EypDE04ii
license:              MIT
copyright:            (c) 2012-2020 Simon Hengel
maintainer:           Simon Hengel <sol@typeful.net>
author:               Simon Hengel <sol@typeful.net>
homepage:             https://github.com/sol/markdown-unlit#readme
synopsis:             Literate Haskell support for Markdown
description:
    Documentation is here: <https://github.com/sol/markdown-unlit#readme>

category:             Development
abi:                  d3cf0bf5910f3dfa0a792e655e5e60cf
exposed:              True
exposed-modules:      Text.Markdown.Unlit
hidden-modules:       Paths_markdown_unlit
import-dirs:          /usr/lib/ghc-9.0.2/site-local/markdown-unlit-0.5.1
library-dirs:         /usr/lib/ghc-9.0.2/site-local/markdown-unlit-0.5.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-markdown-unlit
hs-libraries:         HSmarkdown-unlit-0.5.1-KezIVwL1tmxB3EypDE04ii
depends:
    base-4.15.1.0 base-compat-0.12.1-Jgs1a6JPC25AMVxb7dCwve

haddock-interfaces:
    /usr/share/doc/haskell-markdown-unlit/html/markdown-unlit.haddock

haddock-html:         /usr/share/doc/haskell-markdown-unlit/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-markdown-unlit-0.5.1-112-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-markdown-unlit.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 markdown-unlit
version:              0.5.1
visibility:           public
id:                   markdown-unlit-0.5.1-Blyhka65CHS1DKe2XnU1DJ
key:                  markdown-unlit-0.5.1-Blyhka65CHS1DKe2XnU1DJ
license:              MIT
copyright:            (c) 2012-2020 Simon Hengel
maintainer:           Simon Hengel <sol@typeful.net>
author:               Simon Hengel <sol@typeful.net>
homepage:             https://github.com/sol/markdown-unlit#readme
synopsis:             Literate Haskell support for Markdown
description:
    Documentation is here: <https://github.com/sol/markdown-unlit#readme>

category:             Development
abi:                  293e54ce9b570f861a087e62a4aa41dc
exposed:              True
exposed-modules:      Text.Markdown.Unlit
hidden-modules:       Paths_markdown_unlit
import-dirs:          /usr/lib/ghc-9.0.2/site-local/markdown-unlit-0.5.1
library-dirs:         /usr/lib/ghc-9.0.2/site-local/markdown-unlit-0.5.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-markdown-unlit
hs-libraries:         HSmarkdown-unlit-0.5.1-Blyhka65CHS1DKe2XnU1DJ
depends:
    base-4.15.1.0 base-compat-0.12.1-Jgs1a6JPC25AMVxb7dCwve

haddock-interfaces:
    /usr/share/doc/haskell-markdown-unlit/html/markdown-unlit.haddock

haddock-html:         /usr/share/doc/haskell-markdown-unlit/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
